@@ -1,4 +1,3 @@
-# $Id: FeatureHolderI.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::FeatureHolderI
 #
@@ -69,7 +68,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Hilmar Lapp
 
@@ -78,6 +77,7 @@ Email hlapp at gmx.net
 =head1 CONTRIBUTORS
 
 Steffen Grossmann [SG], grossman-at-molgen.mpg.de
+Mark A. Jensen, maj -at- fortinbras -dot- us
 
 =head1 APPENDIX
 
@@ -99,14 +99,12 @@ use base qw(Bio::Root::RootI);
 
 =head2 get_SeqFeatures()
 
- Usage   :
+ Usage   : @feats = $obj->get_SeqFeatures()
  Function: Get the feature objects held by this feature holder.
  Example :
  Returns : an array of Bio::SeqFeatureI implementing objects
- Args    : none
-
-At some day we may want to expand this method to allow for a feature
-filter to be passed in.
+           if tag specified, return features having that tag
+ Args    : [optional] scalar string (feature tag)
 
 =cut
 
