@@ -37,13 +37,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                 - General discussion
   http://bioperl.org/wiki/Mailing_list  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via
 the web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR
 
@@ -52,7 +63,7 @@ the web:
 =head1 CONTRIBUTORS
 
  Steffen Grossmann, <grossman@molgen.mpg.de>
- Scott Cain, <cain@cshl.edu>
+ Scott Cain, <scain@cpan.org>
  Rob Edwards <rob@salmonella.org>
 
 =head1 APPENDIX
@@ -93,6 +104,8 @@ sub _initialize {
   $self->version( $arg{-version}        || DEFAULT_VERSION);
   $self->validate($arg{-validate_terms} || 0);
 
+  $self->ignore_seq_region($arg{-ignore_seq_region} || 0);
+
   if ($arg{-file} =~ /^>.*/ ) {
     $self->_print("##gff-version " . $self->version() . "\n");
   }
@@ -287,12 +300,21 @@ sub write_feature {
  Returns : value of fasta_mode (a scalar)
  Args    : on set, new value (a scalar or undef, optional)
 
+Side effect when setting: rewind the file handle a little bit to get the last
+carriage return that was swallowed when the previous line was processed.
 
 =cut
 
 sub fasta_mode {
   my($self,$val) = @_;
+
   $self->{'fasta_mode'} = $val if defined($val);
+
+  if ($val && $val == 1) {
+  #  seek $self->_fh(), -1, 1; #rewind 1 byte to get the previous line's \n
+    $self->_pushback("\n");
+  }
+
   return $self->{'fasta_mode'};
 }
 
@@ -424,6 +446,19 @@ sub _buffer_feature {
 }
 
 
+=head1 ignore_seq_region
+
+Set this flag to keep FeatureIO from returning 
+a feature for a ##sequence-region directive
+
+=cut
+
+sub ignore_seq_region {
+  my($self,$val) = @_;
+  $self->{'ignore_seq_region'} = $val if defined($val);
+  return $self->{'ignore_seq_region'};
+}
+
 =head1 _handle_directive()
 
 this method is called for lines beginning with '##'.
@@ -448,6 +483,8 @@ sub _handle_directive {
     # for these we want to store the seqid, start, and end. Then when we validate
     # we want to make sure that the features are within the seqid/start/end
 
+    return if $self->ignore_seq_region();
+
     $self->throw('Both start and end for sequence region should be defined')
       unless $arg[1] && $arg[2];
     my $fta = Bio::Annotation::OntologyTerm->new();
@@ -600,7 +637,14 @@ sub _handle_feature {
       $values =~ s/^["']//;
       $values =~ s/["']$//; #' terminate the quote for emacs
 
-      my @values = map{uri_unescape($_)} split ',', $values;
+      my @values;
+      if ($key eq 'Target') {
+          #dont unescape Target values
+          @values = split ',', $values;
+      }
+      else {
+          @values = map{uri_unescape($_)} split ',', $values
+      }
 
      #minor hack to allow for multiple instances of the same tag
       if ($attr{$key}) {
@@ -889,7 +933,7 @@ sub _write_feature_3 {
   my $max    = $feature->end     || '.';
   my $strand = $feature->strand == 1 ? '+' : $feature->strand == -1 ? '-' : '.';
   my $score  = defined($feature->score) ? (ref($feature->score) ? $feature->score->value : $feature->score) : undef;
-  my $phase  = $feature->phase->value;
+  my $phase  = defined($feature->phase) ? (ref($feature->phase) ? $feature->phase->value : $feature->phase) : undef;
 
   my @attr;
   if(my @v = ($feature->get_Annotations('Name'))){
