@@ -257,7 +257,7 @@ sub new {
               -fh       file handle (mutually exclusive with -file)
               -flush    boolean flag to autoflush after each write
               -noclose  boolean flag, when set to true will not close a
-                        filehandle (must explictly call close($io->_fh)
+                        filehandle (must explicitly call close($io->_fh)
               -retries  number of times to try a web fetch before failure
                         
               -ua_parms hashref of key => value parameters to pass 
@@ -401,7 +401,7 @@ sub _fh {
  Example :
  Returns : mode of filehandle:
            'r' for readable
-           'w' for writeable
+           'w' for writable
            '?' if mode could not be determined
  Args    : -force (optional), see notes.
  Notes   : once mode() has been called, the filehandle's mode is cached
@@ -627,7 +627,7 @@ sub _pushback {
 sub close {
    my ($self) = @_;
 
-   # don't close if we explictly asked not to
+   # don't close if we explicitly asked not to
    return if $self->noclose;
 
    if( defined( my $fh = $self->{'_filehandle'} )) {
@@ -960,7 +960,7 @@ sub rmtree {
     return File::Path::rmtree ($roots, $verbose, $safe);
     }
 
-    my $force_writeable = ($^O eq 'os2' || $^O eq 'dos' || $^O eq 'MSWin32'
+    my $force_writable = ($^O eq 'os2' || $^O eq 'dos' || $^O eq 'MSWin32'
                || $^O eq 'amigaos' || $^O eq 'cygwin');
     my $Is_VMS = $^O eq 'VMS';
 
@@ -986,7 +986,7 @@ sub rmtree {
         # to recurse in which case we are better than rm -rf for 
         # subtrees with strange permissions
         chmod(0777, ($Is_VMS ? VMS::Filespec::fileify($root) : $root))
-          or $self->warn("Can't make directory $root read+writeable: $!")
+          or $self->warn("Can't make directory $root read+writable: $!")
         unless $safe;
         if (opendir(DIR, $root) ){
         @files = readdir DIR;
@@ -1008,8 +1008,8 @@ sub rmtree {
         next;
         }
         chmod 0777, $root
-          or $self->warn( "Can't make directory $root writeable: $!")
-        if $force_writeable;
+          or $self->warn( "Can't make directory $root writable: $!")
+        if $force_writable;
         print "rmdir $root\n" if $verbose;
         if (rmdir $root) {
         ++$count;
@@ -1031,14 +1031,14 @@ sub rmtree {
         next;
         }
         chmod 0666, $root
-          or $self->warn( "Can't make file $root writeable: $!")
-        if $force_writeable;
+          or $self->warn( "Can't make file $root writable: $!")
+        if $force_writable;
         warn "unlink $root\n" if $verbose;
         # delete all versions under VMS
         for (;;) {
         unless (unlink $root) {
             $self->warn( "Can't unlink file $root: $!");
-            if ($force_writeable) {
+            if ($force_writable) {
             chmod $rp, $root
                 or $self->warn("and can't restore permissions to "
                         . sprintf("0%o",$rp) . "\n");
