@@ -1,7 +1,8 @@
-# $Id: TextResultWriter.pm 14480 2008-02-04 23:41:47Z cjfields $
 #
 # BioPerl module for Bio::SearchIO::Writer::TextResultWriter
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Jason Stajich <jason@bioperl.org>
 #
 # Copyright Jason Stajich
@@ -89,13 +90,24 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 of the bugs and their resolution. Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Jason Stajich
 
@@ -237,7 +249,7 @@ sub to_string {
     }
 
     $str .= &{$self->title}($result);
-
+    $str .= $result->algorithm . " " . $result->algorithm_version . "\n\n\n";
     $str .= $result->algorithm_reference || $self->algorithm_reference($result);
     $str .= &{$self->introduction}($result);
 
