@@ -1,7 +1,8 @@
-# $Id: Array.pm 15012 2008-11-24 04:50:37Z cjfields $
 #
 # BioPerl module for Bio::Seq::Meta::Array
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Heikki Lehvaslaiho
 #
 # Copyright Heikki Lehvaslaiho
@@ -25,7 +26,7 @@ sequence class with residue-based meta information
                                    -start=>2434,
                                    -start=>2443,
                                    -strand=>1,
-                                   -varbose=>1, # to see warnings
+                                   -verbose=>1, # to see warnings
                                   );
 
   # to test this is a meta seq object
@@ -41,7 +42,7 @@ sequence class with residue-based meta information
                                     -start=>2443,
                                     -strand=>1,
                                     -meta=>'1 2 3 4 5 6 7 8 9 10',
-                                    -varbose=>1, # to see warnings
+                                    -verbose=>1, # to see warnings
                                    );
 
 
@@ -93,13 +94,24 @@ of the Bioperl mailing lists.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHOR - Heikki Lehvaslaiho
 
@@ -122,21 +134,13 @@ Internal methods are usually preceded with a _
 
 
 package Bio::Seq::Meta::Array;
-use vars qw(@ISA $DEFAULT_NAME $GAP $META_GAP);
 use strict;
 
-use Data::Dumper;
-
-#use overload '""' => \&to_string;
-
 use base qw(Bio::LocatableSeq Bio::Seq Bio::Seq::MetaI);
 
-BEGIN {
-
-    $DEFAULT_NAME = 'DEFAULT';
-    $GAP = '-';
-    $META_GAP = 0;
-}
+our $DEFAULT_NAME = 'DEFAULT';
+our $GAP = '-';
+our $META_GAP = 0;
 
 =head2 new
 
@@ -155,14 +159,19 @@ BEGIN {
 
 sub new {
     my ($class, %args) = @_;
+    
+    # run-time modification of @ISA is extremely evil (you should't pick your
+    # interface on the fly); this has no obvious effect on any tests so
+    # commenting out - cjfields 2011-4-6
+    
 	#defined inheritance according to stated baseclass,
 	#if undefined then will be PrimarySeq
-	if (defined($args{'-baseclass'})) {
-		@ISA = ($args{'-baseclass'},"Bio::Seq::MetaI");
-		}
-	else {
-		@ISA = qw( Bio::LocatableSeq Bio::Seq Bio::Seq::MetaI );
-		}
+	#if (defined($args{'-baseclass'})) {
+	#	@ISA = ($args{'-baseclass'},"Bio::Seq::MetaI");
+	#	}
+	#else {
+	#	@ISA = qw( Bio::LocatableSeq Bio::Seq Bio::Seq::MetaI );
+	#	}
 
     my $self = $class->SUPER::new(%args);
 
