@@ -52,7 +52,7 @@ sub next_dataset {
     my $line = $self->{lastline} || <$fh>;
     
     FASTQ:
-    while ($line) {
+    while (defined $line) {
         $line =~ s/\015\012/\012/;
         $line =~ tr/\015/\n/;
         if ($mode eq '-seq' && $line =~ m{^@([^\n]+)$}xmso) {
@@ -80,7 +80,7 @@ sub next_dataset {
                 last FASTQ
             }
             chomp $line;
-            if (!$line) {
+            if ($line =~ /^$/) {
                 delete $self->{lastline};
                 last FASTQ;
             }
@@ -127,7 +127,7 @@ sub write_seq {
             $self->warn("You can't write FASTQ without supplying a Bio::Seq::Quality object! ", ref($seq), "\n");
             next;
         }
-        my $str = $seq->seq;
+        my $str = $seq->seq || '';
         my @qual = @{$seq->qual};
         
         # this should be the origin of the sequence (illumina, solexa, sanger)
@@ -138,9 +138,6 @@ sub write_seq {
             $desc =~ s/\n//g;
             $top .= " $desc";
         }
-        if(length($str) == 0) {
-            $str = "\n";
-        }
         my $qual = '';
         my $qual_map =
             ($ns eq 'solexa' && $var eq 'solexa') ? $self->{phred_fp2chr} :
@@ -350,7 +347,7 @@ FASTQ flat file databases.
 
 FASTQ is a file format used frequently at the Sanger Centre and in next-gen
 sequencing to bundle a FASTA sequence and its quality data. A typical FASTQ
-entry takes the from:
+entry takes the form:
 
   @HCDPQ1D0501
   GATTTGGGGTTCAAAGCAGTATCGATCAAATAGTAAATCCATTTGTTCAACTCACAGTTT.....
@@ -363,6 +360,10 @@ where:
   + = optional descriptor (if present, must match first one), followed by one or
       more qual lines
 
+When writing FASTQ output the redundant descriptor following the '+' is by
+default left off to save disk space. If needed, one can set the quality_header()
+flag in order for this to be printed.
+
 =head2 FASTQ and Bio::Seq::Quality mapping
 
 FASTQ files have sequence and quality data on single line or multiple lines, and
@@ -436,7 +437,7 @@ Report bugs to the Bioperl bug tracking system to help us keep track
 the bugs and their resolution.  Bug reports can be submitted via the
 web:
 
-  http://bugzilla.open-bio.org/
+  https://redmine.open-bio.org/projects/bioperl/
 
 =head1 AUTHORS - Chris Fields (taken over from Tony Cox)
 
